@@ -1,5 +1,5 @@
 # ************************************************************************* 
-# Copyright (c) 2014, SUSE LLC
+# Copyright (c) 2014-2015, SUSE LLC
 # 
 # All rights reserved.
 # 
@@ -41,7 +41,7 @@ use App::CELL qw( $CELL );
 use App::Dochazka::CLI qw( $current_emp $debug_mode );
 use App::Dochazka::CLI::Shared qw( print_schedule_object show_current );
 use App::Dochazka::CLI::Util qw( lookup_employee parse_test rest_error );
-use App::Dochazka::Model::Schedule;
+use App::Dochazka::Common::Model::Schedule;
 use Data::Dumper;
 use Exporter 'import';
 use JSON;
@@ -57,17 +57,6 @@ App::Dochazka::CLI::Commands::Schedule - Schedule commands
 
 
 
-=head1 VERSION
-
-Version 0.197
-
-=cut
-
-our $VERSION = '0.197';
-
-
-
-
 =head1 PACKAGE VARIABLES
 
 =cut
@@ -241,7 +230,7 @@ sub fetch_all_schedules {
     if ( $status->ok ) {
         my $pl = '';
         foreach my $sch_hash ( @{ $status->payload } ) {
-            my $sch_obj = App::Dochazka::Model::Schedule->spawn( %$sch_hash );
+            my $sch_obj = App::Dochazka::Common::Model::Schedule->spawn( %$sch_hash );
             $pl .= print_schedule_object( $sch_obj );
             $pl .= "\n";
         }
@@ -330,7 +319,7 @@ sub schedule_new {
 
     my $status = send_req( 'POST', 'schedule/new', $json );
     if ( $status->ok ) {
-        my $sch_obj = App::Dochazka::Model::Schedule->spawn( %{ $status->payload } );
+        my $sch_obj = App::Dochazka::Common::Model::Schedule->spawn( %{ $status->payload } );
         my $pl = '';
         if ( my $http_status = $status->{'http_status'} ) {
             $pl .= "HTTP status: $http_status\n";
@@ -394,7 +383,7 @@ sub schedulespec {
     }
 
     if ( $status->ok ) {
-        my $sch_obj = App::Dochazka::Model::Schedule->spawn( %{ $status->payload } );
+        my $sch_obj = App::Dochazka::Common::Model::Schedule->spawn( %{ $status->payload } );
         $pl = print_schedule_object( $sch_obj );
         return $CELL->status_ok( "DOCHAZKA_CLI_NORMAL_COMPLETION", payload => $pl );
     }
@@ -434,7 +423,7 @@ EOS
     }
 
     if ( $status->level eq 'OK' and $status->code eq 'DOCHAZKA_CUD_OK' ) {
-        my $sch_obj = App::Dochazka::Model::Schedule->spawn( %{ $status->payload } );
+        my $sch_obj = App::Dochazka::Common::Model::Schedule->spawn( %{ $status->payload } );
         my $pl = print_schedule_object( $sch_obj );
         return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $pl );
     }
@@ -472,7 +461,7 @@ EOS
     }
 
     if ( $status->level eq 'OK' and $status->code eq 'DOCHAZKA_CUD_OK' ) {
-        my $sch_obj = App::Dochazka::Model::Schedule->spawn( %{ $status->payload } );
+        my $sch_obj = App::Dochazka::Common::Model::Schedule->spawn( %{ $status->payload } );
         my $pl = print_schedule_object( $sch_obj );
         return $CELL->status_ok( 'DOCHAZKA_CLI_NORMAL_COMPLETION', payload => $pl );
     }
